@@ -15,7 +15,7 @@ namespace Botan {
 /**
 * Simple String
 */
-class BOTAN_DLL ASN1_String : public ASN1_Object
+class BOTAN_DLL ASN1_String final : public ASN1_Object
    {
    public:
       void encode_into(class DER_Encoder&) const override;
@@ -29,8 +29,8 @@ class BOTAN_DLL ASN1_String : public ASN1_Object
       ASN1_String(const std::string& = "");
       ASN1_String(const std::string&, ASN1_Tag);
    private:
-      std::string iso_8859_str;
-      ASN1_Tag tag;
+      std::string m_iso_8859_str;
+      ASN1_Tag m_tag;
    };
 
 }
