@@ -17,7 +17,7 @@ namespace Botan {
 /**
 * Keccak[1600], a SHA-3 candidate
 */
-class BOTAN_DLL Keccak_1600 : public HashFunction
+class BOTAN_DLL Keccak_1600 final : public HashFunction
    {
    public:
 
@@ -27,8 +27,8 @@ class BOTAN_DLL Keccak_1600 : public HashFunction
       */
       Keccak_1600(size_t output_bits = 512);
 
-      size_t hash_block_size() const override { return bitrate / 8; }
-      size_t output_length() const override { return output_bits / 8; }
+      size_t hash_block_size() const override { return m_bitrate / 8; }
+      size_t output_length() const override { return m_output_bits / 8; }
 
       HashFunction* clone() const override;
       std::string name() const override;
@@ -37,9 +37,9 @@ class BOTAN_DLL Keccak_1600 : public HashFunction
       void add_data(const byte input[], size_t length) override;
       void final_result(byte out[]) override;
 
-      size_t output_bits, bitrate;
-      secure_vector<u64bit> S;
-      size_t S_pos;
+      size_t m_output_bits, m_bitrate;
+      secure_vector<u64bit> m_S;
+      size_t m_S_pos;
    };
 
 }
